/**
 * This script will find and highlight all video events 
 * to the right of the cursor if they contain the specified fX.
 *
 * Written By: John Meyer
 * 12-11-2003
 **/

import System;
import System.Collections;
import System.Text;
import System.IO;
import System.Drawing;
import System.Windows.Forms;
import Sony.Vegas;

try {
  var AllFinished = false;
  // Change this line to the name of the fX you want to find.
  var plugInName = "PluginPac Adapter";
  var fx = Vegas.VideoFX;
  var plugIn = fx.GetChildByName(plugInName);
  if (null == plugIn) {
    throw "could not find a plug-in named: '" + plugInName + "'";
  }

  var track = FindSelectedTrack(); //Use this function to find the first selected track.  

  //Go through the list of Events
  var eventEnum = new Enumerator(track.Events);
  var evnt : TrackEvent = TrackEvent(eventEnum.item());
  if ( evnt.IsVideo() ) {             // Only operate on video events
    while (!eventEnum.atEnd()) {
      evnt = TrackEvent(eventEnum.item());
      // Only operate on events to the right of the cursor.
      if (evnt.Start.ToMilliseconds() > Vegas.Cursor.ToMilliseconds() ) {
        var videoEvent = VideoEvent(evnt);
        var i;
        for (i=videoEvent.Effects.Count - 1; i >= 0; i--) {  // Look through all effects for this event.
          var effect = videoEvent.Effects[i];
          if (effect.PlugIn.Name == plugIn.Name) {
            evnt.Selected = true;  // Select the event
            Vegas.Cursor = evnt.Start;
            Vegas.UpdateUI();  
            AllFinished = true;
            break;
          }
        }
      }
      else {
        evnt.Selected = false;  // De-select the event
      }
      if (AllFinished) {
        Vegas.UpdateUI();
        break;
      }
      eventEnum.moveNext();
    }
  }
 Vegas.UpdateUI();  

} catch (e) {
    MessageBox.Show(e);
}

function FindSelectedTrack() : Track {
  var trackEnum = new Enumerator(Vegas.Project.Tracks);
  while (!trackEnum.atEnd()) {
    var track : Track = Track(trackEnum.item());

    if (track.Selected) {
      return track;
    }
    trackEnum.moveNext();
  }
  return null;
}