//
// FilmLook.js
//
// Version:      @(#) FilmLook.js 1.1 07-Feb-2003 pgf@pgf.org
//
// 1.0 - Initial Version (For Use With Vegas 4.0 Beta Build 74)
// 1.1 - Update (For Use With Vegas 4.0 Final Build 115)
//       Now Includes Render Template Configuration Variable
//

// Choose A Render Template
var gRenderTemplate = /NTSC DV$/;
// var gRenderTemplate = /NTSC DV Widescreen$/;
// var gRenderTemplate = /PAL DV$/;
// var gRenderTemplate = /PAL DV Widescreen$/;

import System.IO;
import System.Windows.Forms;
import Sony.Vegas;

// Execute Main Function
fMain();

function fMain() {

  try {

    // Create A New Project
    Vegas.NewProject(true, false);

    // Obtain Filenames To Process
    var aMedia = fOpenFile("Video for Windows (*.avi)|*.avi");
    if (aMedia == null) return;

    for (var i = 0; i < aMedia.length; i++) {

      // Generate Temporary Filename
      var sUpper = aMedia[i].substring(0, aMedia[i].LastIndexOf('.')) + " UPPER.avi";

      // Generate Final Filename
      var sFinal = aMedia[i].substring(0, aMedia[i].LastIndexOf('.')) + " FINAL.avi";

      // Add Original Video To Timeline
      fAddVideoTrack(aMedia[i], 0);

      // Add Original Audio To Timeline
      fAddAudioTrack(aMedia[i], 2);

      // Set Project Field Order To Upper Field First
      Vegas.Project.Video.FieldOrder = VideoFieldOrder.UpperFieldFirst;

      // Render Temporary Video/Audio To Disk
      var oRenderStatus = fRenderProject(sUpper, /Video for Windows/, gRenderTemplate)
      if (oRenderStatus != RenderStatus.Complete) {
        throw new Error(1, "Render of Temporary Media Incomplete");
      }

      // Set Project Field Order To Lower Field First
      Vegas.Project.Video.FieldOrder = VideoFieldOrder.LowerFieldFirst;

      // Add Temporary Video To Timeline
      fAddVideoTrack(sUpper, 1);

      // Set Temporary Video Field Order To Upper Field First
      var oMedia = Vegas.Project.MediaPool.Find(Vegas.Project.Tracks[1].Events[0].ActiveTake.MediaPath)
      oMedia.Streams[0].FieldOrder = VideoFieldOrder.UpperFieldFirst;

      // Add Composite Level Envelope To Original Video
      var oCompositeEnvelope = new Envelope(EnvelopeType.Composite);
      Vegas.Project.Tracks[0].Envelopes.Add(oCompositeEnvelope);
      oCompositeEnvelope.Points[0].Y = 0.5;

      // Render Final Video/Audio To Disk
      oRenderStatus = fRenderProject(sFinal, /Video for Windows/, gRenderTemplate);
      if (oRenderStatus != RenderStatus.Complete) {
        throw new Error(2, "Render of Final Media Incomplete");
      }

      // Create A New Project
      Vegas.NewProject(false, false);

      // Delete Temporary Video From Disk
      File.Delete(sUpper);

    }

  } catch(e) {

    MessageBox.Show(e, "An Error Has Occurred", MessageBoxButtons.OK, MessageBoxIcon.Error);

  } finally {

    // Create A New Project
    Vegas.NewProject(false, false);

  }
}

function fAddVideoTrack(sFilename, iIndex) {
  var oTrack  = new VideoTrack(iIndex);
  var oMedia  = new Media(sFilename);
  var oStream = oMedia.Streams[0];
  var oLength = oStream.Length;
  var oEvent  = new VideoEvent(new Timecode(0), oLength);

  Vegas.UpdateUI();

  Vegas.Project.Tracks.Add(oTrack);
  oTrack.Events.Add(oEvent);
  oEvent.Takes.Add(new Take(oStream));

  Vegas.UpdateUI();
}

function fAddAudioTrack(sFilename, iIndex) {
  var oTrack  = new AudioTrack(iIndex);
  var oMedia  = new Media(sFilename);
  var oStream = oMedia.Streams[1];
  var oLength = oStream.Length;
  var oEvent  = new AudioEvent(new Timecode(0), oLength);

  Vegas.UpdateUI();

  Vegas.Project.Tracks.Add(oTrack);
  oTrack.Events.Add(oEvent);
  oEvent.Takes.Add(new Take(oStream));

  Vegas.UpdateUI();
}

function fRenderProject(sOutputFile, sRenderType, sRenderTemplate) {
  var eRenderers = new Enumerator(Vegas.Renderers);
  var oRenderer;

  Vegas.UpdateUI();

  while (!eRenderers.atEnd()) {
    oRenderer = eRenderers.item();

    if (oRenderer.FileTypeName.match(sRenderType) != null) {
      var eTemplates = new Enumerator(oRenderer.Templates);
      var oTemplate;

      while (!eTemplates.atEnd()) {
        oTemplate = eTemplates.item();

        if (oTemplate.Name.match(sRenderTemplate) != null) {
          return Vegas.Render(sOutputFile, oTemplate, new Timecode(0), Vegas.Project.Length);
        }

        eTemplates.moveNext();
      }
    }

    eRenderers.moveNext();
  }

  Vegas.UpdateUI();
}

function fOpenFile(sFilter) {
  var oOpenFileDialog = new OpenFileDialog();

  oOpenFileDialog.Filter = sFilter;
  oOpenFileDialog.CheckPathExists = true;
  oOpenFileDialog.ShowReadOnly = false;
  oOpenFileDialog.AddExtension = true;
  oOpenFileDialog.Multiselect = true;

  if (oOpenFileDialog.ShowDialog() == System.Windows.Forms.DialogResult.OK) {
    var aFileNames = oOpenFileDialog.FileNames;

    for (var i = 0; i < aFileNames.length; i++) {
      aFileNames[i] = Path.GetFullPath(aFileNames[i]);
    }

    return aFileNames;
  } else {
    return null;
  }
}

